@@ -11,12 +11,14 @@ from copy import deepcopy
 
 
 class BasicGraph:
-	def __init__(self, strict=True, ordering=True):
+	def __init__(self, strict=True, ordering=True, node_label_converter=None, edge_label_converter=None):
 		self._nodes_dict = {}
 		self._is_strict = strict
 		self._ordering = ordering
 		self._nodes_have_graph = True
 		self._node_counter = 0
+		self._node_label_converter = node_label_converter
+		self._edge_label_converter = edge_label_converter
 		# if a dictionary or an object with a __graph__() method is passed use that to create the graph
 
 	_STATE_ATTRIBUTES = ['_nodes_dict', '_is_strict', '_ordering', '_node_counter']
@@ -169,20 +171,24 @@ class BasicGraph:
 		:type node: Node or str
 		:rtype: Node
 		"""
-		if isinstance(node, str):
+		if isinstance(node, (str, int)):
 			return self.nodes_dict[node]
-		else:
+		elif isinstance(node, Node):
 			return self.nodes_dict[node.id]
+		else:
+			raise TypeError(f'node of type {type(node)} is not supported!')
 
 	def get_node_name(self, node):
 		"""
 		:type node: Node or str
 		:rtype: Node
 		"""
-		if isinstance(node, str):
+		if isinstance(node, (str, int)):
 			return self.nodes_dict[node].id
-		else:
+		elif isinstance(node, Node):
 			return node.id
+		else:
+			raise TypeError(f'node of type {type(node)} is not supported!')
 
 	def generate_node_index(self):
 		index = self._node_counter
@@ -195,7 +201,7 @@ class BasicGraph:
 		:param str name: name of the new node
 		:param str or NoneType label: a label for the node
 		:param value: node value
-		:param NodeStyle or str style: style of the node
+		:param NodeStyle or str or dict[str, str] style: style of the node
 		:param str if_node_exists: what to do if a node with that name exists. One of 'warn', 'error', 'ignore'
 		:param kwargs:
 		:rtype: Node
