@@ -256,8 +256,8 @@ class GraphWithoutDisplay(BasicGraph):
 		if self._tooltip is not None:
 			attributes['tooltip'] = f'"{self._tooltip}"'
 
-		if dpi is not None:
-			attributes['dpi'] = f'{dpi}'
+		#if dpi is not None:
+		#	attributes['dpi'] = f'{dpi}'
 		for key, value in self._kwargs.items():
 			if isinstance(value, int):
 				attributes[key] = value
@@ -265,7 +265,7 @@ class GraphWithoutDisplay(BasicGraph):
 				attributes[key] = f'"{value}"'
 
 		if len(attributes) > 0:
-			second_part += '\tGraph [' + ', '.join([f'{key} = {value}' for key, value in attributes.items()]) + ' ];\n'
+			second_part += '\t graph [' + ', '.join([f'{key} = {value}' for key, value in attributes.items()]) + ' ];\n'
 
 		second_part += f'\tbgcolor="{self.background_colour.hexadecimal}";\n'
 
